summaryrefslogtreecommitdiffstats
path: root/kkbswitch/kbconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'kkbswitch/kbconfig.h')
-rw-r--r--kkbswitch/kbconfig.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kkbswitch/kbconfig.h b/kkbswitch/kbconfig.h
index c5ecaac..5ff3936 100644
--- a/kkbswitch/kbconfig.h
+++ b/kkbswitch/kbconfig.h
@@ -22,7 +22,7 @@
#include <ntqptrvector.h>
#include <ntqvaluevector.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#define ICONS_SECTION "Icons"
#define OPTIONS_SECTION "Options"
@@ -30,7 +30,7 @@
#define FLAG_ICON_WIDTH 21
#define FLAG_ICON_HEIGHT 14
-class KGlobalAccel;
+class TDEGlobalAccel;
typedef TQPtrVector<KBGroup> KBGroupVector;
@@ -51,7 +51,7 @@ private:
bool m_autostart;
bool m_use_shortcuts;
IconStyle m_icon_style;
- KGlobalAccel *m_keys;
+ TDEGlobalAccel *m_keys;
public:
KBConfig();
~KBConfig();
@@ -72,11 +72,11 @@ public:
void set_icon_style(IconStyle value) { m_icon_style = value; }
bool use_shortcuts() { return m_use_shortcuts; }
void set_use_shortcuts(bool value) { m_use_shortcuts = value; }
- KGlobalAccel *keys() { return m_keys; }
- /** Load the KBSwitch configration from the application KConfig object */
- void load(KConfig *config);
- /** Save the KBSwitch configration to the application KConfig object */
- void save(KConfig *config);
+ TDEGlobalAccel *keys() { return m_keys; }
+ /** Load the KBSwitch configration from the application TDEConfig object */
+ void load(TDEConfig *config);
+ /** Save the KBSwitch configration to the application TDEConfig object */
+ void save(TDEConfig *config);
/** No descriptions */
/*void notifyChanged();*/
/*static TQString entryForGroup(int i) {
@@ -94,16 +94,16 @@ private: // Private methods
/** No descriptions */
//void drawDefaultPixmaps();
/** No descriptions */
- //void loadConfiguredPixmaps(KConfig *config);
+ //void loadConfiguredPixmaps(TDEConfig *config);
void drawFlagPixmap(TQPixmap &pix, TQString &path, const TQString &code,
- int group, KConfig *config);
+ int group, TDEConfig *config);
void drawCodePixmap(TQPixmap &pix, const TQString &code);
void drawCodeAndFlagPixmap(TQPixmap &pix, TQString &path,
const TQString &countryCode, const TQString &langCode, int group,
- KConfig *config);
+ TDEConfig *config);
void drawDefaultPixmap(TQPixmap &pix, int group);
bool getGroupImage(TQImage &img, TQString &path, const TQString &code, int group,
- KConfig *config);
+ TDEConfig *config);
void getXkbLayouts(TQStringList &layouts);
};